class lead:
    def __init__(self):
        self.obj = [
            'Bill Gates', 
            'Jeff Bezos', 
            'Elon Musk', 
            'Linus Torvalds',
            'Evan Spiegel',
            'Richard Hendricks'
        ]
 
 
    def displayLead(self):
        print('Displaying a handful of the most influental tech leaders!')
        for __it__ in self.obj:
            print('\t%s ' % __it__)



from comp_lead.leaders import lead
from comp_lead.companies import comp
   
# Create an object and call it
obj = lead() 
obj.displayLead()

# Create an object and call it
com = comp() 
com.displayComp()



class comp:
    def __init__(self):
        self.com = [
            'Google', 
            'Microsoft', 
            'Amazon', 
            'Apple', 
            'Facebook',
            'Pied Piper'
        ]
 
 
    def displayComp(self):
        print('Displaying a handful of the most influental tech companies!')
        for __it__ in self.com:
            print('\t%s ' % __it__)
